@@ -5,8 +5,10 @@ function _aws_cdk_aws_wisdom_CfnAssistantProps(p) {
     try {
         if (!visitedObjects.has(p.serverSideEncryptionConfiguration))
             _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty(p.serverSideEncryptionConfiguration);
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -21,8 +23,10 @@ function _aws_cdk_aws_wisdom_CfnAssistantAssociationProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
@@ -37,8 +41,10 @@ function _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps(p) {
         return;
     visitedObjects.add(p);
     try {
-        if (!visitedObjects.has(p.tags))
-            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+        if (p.tags != null)
+            for (const o of p.tags)
+                if (!visitedObjects.has(o))
+                    require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(o);
     }
     finally {
         visitedObjects.delete(p);
